import axios from 'axios'
import { MessageBox, Message } from 'element-ui'
import { getToken, getCodeToken, TokenKey } from '@/utils/auth'
import store from '@/store'
let isMttoken
// create an axios instance
const service = axios.create({
  //baseURL: baseURL, // url = base url + request url
  // baseURL: 'http://106.14.243.117:9112',
  //baseURL: 'http://106.14.243.117:9111',
  baseURL: `${PLATFROM_CONFIG.baseNewUrl}`,
  // withCredentials: true, // send cookies when cross-domain requests
  timeout: 30000, // request timeout
  headers: {
    'Content-Type': 'application/json'
  },
})
axios.defaults.withCredentials = true
// request interceptor
service.interceptors.request.use(
  config => {
    // config.headers.common["content-type"] = "application/json"
    if (config.istoken) {
      config.headers['appSecret'] = PLATFROM_CONFIG.appKeyString
      isMttoken = config.istoken
    } else if (getToken()) {
      config.headers["token"] = getToken();
    }
    return config
  },
  error => {
    // do something with request error

    return Promise.reject(error)
  }
)

// response interceptor
service.interceptors.response.use(
  /**
   * If you want to get http information such as headers or status
   * Please return  response => response
  */

  /**
   * Determine the request status by custom code
   * Here is just an example
   * You can also judge the status by HTTP Status Code
   */
  response => {
    const res = response.data

    // if the custom code is not 20000, it is judged as an error.
    if (res.code != 0) {
      Message({
        message: res.message || 'Error',
        type: 'error',
        duration: 5 * 1000
      })

      // 50008: Illegal token; 50012: Other clients logged in; 50014: Token expired;
      if (!isMttoken) {
        if (res.code == 500) {
          // to re-login
          Message({
            message: '身份令牌过期或失效，即将重新登录',
            type: 'error',
            duration: 5 * 1000,
            onClose: () => {
              store.dispatch('user/resetToken').then(() => {
                location.reload()
              })
            }
          })
        }
      }
      return Promise.reject(new Error(res.message || 'Error'))
    } else {
      return res
    }
  },
  error => {
    if (isMttoken) {
      store.dispatch("user/setIsLogin", true);
    }

    // const des = `${error}`.split(" ").includes('500')
    // if (des) {
    //   Message({
    //     message: '身份令牌过期或失效，即将重新登录',
    //     type: 'error',
    //     duration: 5 * 1000,
    //     onClose: () => {
    //       store.dispatch('user/resetToken').then(() => {
    //         location.reload()
    //       })
    //     }
    //   })
    //   // MessageBox.confirm('You have been logged out, you can cancel to stay on this page, or log in again', 'Confirm logout', {
    //   //   confirmButtonText: 'Re-Login',
    //   //   cancelButtonText: 'Cancel',
    //   //   type: 'warning'
    //   // }).then(() => {
    //   //   store.dispatch('user/resetToken').then(() => {
    //   //     location.reload()
    //   //   })
    //   // })
    // } else {
    //   Message({
    //     message: error.message,
    //     type: 'error',
    //     duration: 5 * 1000
    //   })
    // }
    //loadingInstance.close()
    return Promise.reject(error)
  }
)

export default service
